Rebrand to flashprog and update URLs

Mostly automated `sed` work. As of now, URLs to the old wiki are broken
either way, so changing them shouldn't hurt. Other URLs (e.g. to mailing
list archives) were hopefully filtered correctly.

Change-Id: I9d43bfd0e675eff2fcbad05f304b9ce9f5006b08
Signed-off-by: Nico Huber <nico.h@gmx.de>
Reviewed-on: https://review.sourcearcade.org/c/flashrom-stable/+/21
diff --git a/util/getversion.sh b/util/getversion.sh
index 6733af0..038adcd 100755
--- a/util/getversion.sh
+++ b/util/getversion.sh
@@ -33,8 +33,8 @@
 
 mandate() {
 	d='unknown'
-	if ${GETREVISION} -c flashrom.8.tmpl; then
-		tmp=$(${GETREVISION} --date flashrom.8.tmpl)
+	if ${GETREVISION} -c flashprog.8.tmpl; then
+		tmp=$(${GETREVISION} --date flashprog.8.tmpl)
 		if [ $? -eq 0 ]; then
 			d="${tmp}"
 		fi
@@ -55,7 +55,7 @@
     -h or --help
         this message
     -v or --version
-        return current/release flashrom version
+        return current/release flashprog version
     -m or --man-date
         return current/release date of the manual page
 "
diff --git a/util/git-hooks/commit-msg b/util/git-hooks/commit-msg
index d43eb45..fa250f3 100755
--- a/util/git-hooks/commit-msg
+++ b/util/git-hooks/commit-msg
@@ -28,7 +28,7 @@
 CHANGE_ID_AFTER="Bug|Depends-On|Issue|Test|Feature|Fixes|Fixed|Staging-ID"
 MSG="$1"
 
-DEV_GUIDELINES_URL="https://www.flashrom.org/Development_Guidelines"
+DEV_GUIDELINES_URL="https://www.flashprog.org/Development_Guidelines"
 
 # Check for, and add if missing, a unique Change-Id
 #
diff --git a/util/git-hooks/pre-push b/util/git-hooks/pre-push
index b5f4620..f6e04ec 100755
--- a/util/git-hooks/pre-push
+++ b/util/git-hooks/pre-push
@@ -21,7 +21,7 @@
 
 zero=0000000000000000000000000000000000000000
 
-upstream_pattern="github\.com.flashrom/flashrom(\.git)?|flashrom\.org.git/flashrom(\.git)?"
+upstream_pattern="github\.com.flashprog/flashprog(\.git)?|flashprog\.org.git/flashprog(\.git)?"
 
 # Only care about the upstream repositories
 if echo "$url" | grep -q -v -E "$upstream_pattern" ; then
diff --git a/util/ich_descriptors_tool/Makefile b/util/ich_descriptors_tool/Makefile
index 0891599..14e6d2f 100644
--- a/util/ich_descriptors_tool/Makefile
+++ b/util/ich_descriptors_tool/Makefile
@@ -2,7 +2,7 @@
 # This file is part of the flashrom project.
 #
 # This Makefile works standalone, but it is usually called from the main
-# Makefile in the flashrom directory.
+# Makefile in the flashprog directory.
 
 include ../../Makefile.include
 
@@ -35,14 +35,14 @@
 ifeq ($(TARGET_OS), DOS)
 EXEC_SUFFIX := .exe
 # DJGPP has odd uint*_t definitions which cause lots of format string warnings.
-FLASHROM_CFLAGS += -Wno-format
+FLASHPROG_CFLAGS += -Wno-format
 endif
 
 ifeq ($(TARGET_OS), MinGW)
 EXEC_SUFFIX := .exe
 # Some functions provided by Microsoft do not work as described in C99 specifications. This macro fixes that
 # for MinGW. See http://sourceforge.net/p/mingw-w64/wiki2/printf%20and%20scanf%20family/
-FLASHROM_CFLAGS += -D__USE_MINGW_ANSI_STDIO=1
+FLASHPROG_CFLAGS += -D__USE_MINGW_ANSI_STDIO=1
 endif
 
 ifeq ($(WARNERROR), yes)
@@ -50,10 +50,10 @@
 endif
 
 
-FLASHROM_CFLAGS += -MMD -MP -MF $(DEPPATH)/$(@F).d
+FLASHPROG_CFLAGS += -MMD -MP -MF $(DEPPATH)/$(@F).d
 # enables functions that populate the descriptor structs from plain binary dumps
-FLASHROM_CFLAGS += -D ICH_DESCRIPTORS_FROM_DUMP_ONLY
-FLASHROM_CFLAGS += $(patsubst %,-I%,$(EXTRAINCDIRS))
+FLASHPROG_CFLAGS += -D ICH_DESCRIPTORS_FROM_DUMP_ONLY
+FLASHPROG_CFLAGS += $(patsubst %,-I%,$(EXTRAINCDIRS))
 
 OBJ = $(OBJATH)/$(SRC:%.c=%.o)
 
@@ -62,12 +62,12 @@
 all:$(PROGRAM)$(EXEC_SUFFIX)
 
 $(OBJ): $(OBJATH)/%.o : %.c
-	$(CC) $(CFLAGS) $(CPPFLAGS) $(FLASHROM_CFLAGS) -o $@ -c $<
+	$(CC) $(CFLAGS) $(CPPFLAGS) $(FLASHPROG_CFLAGS) -o $@ -c $<
 
 # this enables us to share source files without simultaneously sharing .o files
-# with flashrom, which would lead to unexpected results (w/o running make clean)
+# with flashprog, which would lead to unexpected results (w/o running make clean)
 $(SHAREDOBJ): $(OBJATH)/%.o : $(SHAREDSRCDIR)/%.c
-	$(CC) $(CFLAGS) $(CPPFLAGS) $(FLASHROM_CFLAGS) -o $@ -c $<
+	$(CC) $(CFLAGS) $(CPPFLAGS) $(FLASHPROG_CFLAGS) -o $@ -c $<
 
 $(PROGRAM)$(EXEC_SUFFIX): $(OBJ) $(SHAREDOBJ)
 	$(CC) $(LDFLAGS) -o $(PROGRAM)$(EXEC_SUFFIX) $(OBJ) $(SHAREDOBJ)
diff --git a/util/manibuilder/Dockerfile.almalinux b/util/manibuilder/Dockerfile.almalinux
index 5904f45..8f3502d 100644
--- a/util/manibuilder/Dockerfile.almalinux
+++ b/util/manibuilder/Dockerfile.almalinux
@@ -19,10 +19,10 @@
 ENV GIT_SSL_NO_VERIFY=1
 USER mani
 
-ARG ORIGIN=https://review.coreboot.org/flashrom-stable.git
+ARG ORIGIN=https://review.sourcearcade.org/flashprog.git
 RUN \
 	cd && \
-	git clone ${ORIGIN} flashrom
+	git clone ${ORIGIN} flashprog
 
 ENV DEVSHELL /bin/bash
 COPY mani-wrapper.sh /home/mani/
diff --git a/util/manibuilder/Dockerfile.alpine b/util/manibuilder/Dockerfile.alpine
index 227eb91..585275b 100644
--- a/util/manibuilder/Dockerfile.alpine
+++ b/util/manibuilder/Dockerfile.alpine
@@ -23,11 +23,11 @@
 ENV GIT_SSL_NO_VERIFY=1
 USER mani
 
-ARG ORIGIN=https://review.coreboot.org/flashrom-stable.git
+ARG ORIGIN=https://review.sourcearcade.org/flashprog.git
 RUN \
 	cd && \
 	mkdir .ccache && chown mani:mani .ccache && \
-	git clone ${ORIGIN} flashrom
+	git clone ${ORIGIN} flashprog
 
 ARG IDENT=mani
 ARG CCACHE_MAX=32M
diff --git a/util/manibuilder/Dockerfile.anita b/util/manibuilder/Dockerfile.anita
index b90311f..c8dfae8 100644
--- a/util/manibuilder/Dockerfile.anita
+++ b/util/manibuilder/Dockerfile.anita
@@ -25,7 +25,7 @@
 
 ARG EXTRA_PKG=""
 ARG RUNTIME_MEM=128M
-ARG ORIGIN=https://review.coreboot.org/flashrom-stable.git
+ARG ORIGIN=https://review.sourcearcade.org/flashprog.git
 ARG PKG_PATH=http://cdn.netbsd.org/pub/pkgsrc/packages/NetBSD/amd64/7.1/All
 RUN cd && anita --persist --memory-size=${RUNTIME_MEM} --run \
 "echo 'dhcpcd'                                   >init && \
@@ -35,7 +35,7 @@
          pciutils libusb1 libusb-compat libftdi \
          ${EXTRA_PKG} && \
  git config --global --add http.sslVerify false && \
- git clone ${ORIGIN} flashrom" \
+ git clone ${ORIGIN} flashprog" \
 		boot ${INST_IMG}
 
 RUN cd && dd if=/dev/zero bs=1M count=64 of=cache.img && \
@@ -56,7 +56,7 @@
  echo 'manitest() {'                            >>init && \
  echo '    fsck -y -t ffs /dev/'\${bdev}        >>init && \
  echo '    mount /dev/'\${bdev}' ~/.ccache'     >>init && \
- echo '    (cd ~/flashrom && eval \" \$*\")'    >>init && \
+ echo '    (cd ~/flashprog && eval \" \$*\")'    >>init && \
  echo '    ret=\$?'                             >>init && \
  echo '    umount ~/.ccache'                    >>init && \
  echo '    return \$ret'                        >>init && \
diff --git a/util/manibuilder/Dockerfile.centos b/util/manibuilder/Dockerfile.centos
index 6ca5214..72c7472 100644
--- a/util/manibuilder/Dockerfile.centos
+++ b/util/manibuilder/Dockerfile.centos
@@ -11,11 +11,11 @@
 ENV GIT_SSL_NO_VERIFY=1
 USER mani
 
-ARG ORIGIN=https://review.coreboot.org/flashrom-stable.git
+ARG ORIGIN=https://review.sourcearcade.org/flashprog.git
 RUN \
 	cd && \
 	mkdir .ccache && chown mani:mani .ccache && \
-	git clone ${ORIGIN} flashrom
+	git clone ${ORIGIN} flashprog
 
 ENV DEVSHELL /bin/bash
 COPY mani-wrapper.sh /home/mani/
diff --git a/util/manibuilder/Dockerfile.debian b/util/manibuilder/Dockerfile.debian
index 8eeb4ea..ada61d4 100644
--- a/util/manibuilder/Dockerfile.debian
+++ b/util/manibuilder/Dockerfile.debian
@@ -14,11 +14,11 @@
 ENV GIT_SSL_NO_VERIFY=1
 USER mani
 
-ARG ORIGIN=https://review.coreboot.org/flashrom-stable.git
+ARG ORIGIN=https://review.sourcearcade.org/flashprog.git
 RUN \
 	cd && \
 	mkdir .ccache && chown mani:mani .ccache && \
-	git clone ${ORIGIN} flashrom
+	git clone ${ORIGIN} flashprog
 
 ARG IDENT=mani
 ARG CCACHE_MAX=32M
diff --git a/util/manibuilder/Dockerfile.djgpp b/util/manibuilder/Dockerfile.djgpp
index 36cabfe..7547798 100644
--- a/util/manibuilder/Dockerfile.djgpp
+++ b/util/manibuilder/Dockerfile.djgpp
@@ -11,21 +11,21 @@
 ENV GIT_SSL_NO_VERIFY=1
 USER mani
 
-ARG ORIGIN=https://review.coreboot.org/flashrom-stable.git
+ARG ORIGIN=https://review.sourcearcade.org/flashprog.git
 RUN cd && \
 	mkdir .ccache && chown mani:users .ccache && \
-	git clone ${ORIGIN} flashrom && \
+	git clone ${ORIGIN} flashprog && \
 	git clone https://git.kernel.org/pub/scm/utils/pciutils/pciutils.git && \
 	cd pciutils && \
 		git checkout v3.5.6 && \
-		curl --insecure https://flashrom.org/images/6/6a/Pciutils-3.5.6.patch.gz | zcat | git apply && \
+		curl --insecure https://flashprog.org/images/6/6a/Pciutils-3.5.6.patch.gz | zcat | git apply && \
 		make ZLIB=no DNS=no HOST=i386-djgpp-djgpp \
 			CROSS_COMPILE=i586-pc-msdosdjgpp- \
 			PREFIX=/ DESTDIR=$PWD/../ \
 			STRIP="--strip-program=i586-pc-msdosdjgpp-strip -s" \
 			install install-lib && \
 		cd ../ && \
-	curl --insecure https://flashrom.org/images/3/3d/Libgetopt.tar.gz | zcat | tar x && \
+	curl --insecure https://flashprog.org/images/3/3d/Libgetopt.tar.gz | zcat | tar x && \
 	cd libgetopt && \
 		make && cp libgetopt.a ../lib/ && cp getopt.h ../include/
 
diff --git a/util/manibuilder/Dockerfile.fedora b/util/manibuilder/Dockerfile.fedora
index 82a1e21..ccce010 100644
--- a/util/manibuilder/Dockerfile.fedora
+++ b/util/manibuilder/Dockerfile.fedora
@@ -12,11 +12,11 @@
 ENV GIT_SSL_NO_VERIFY=1
 USER mani
 
-ARG ORIGIN=https://review.coreboot.org/flashrom-stable.git
+ARG ORIGIN=https://review.sourcearcade.org/flashprog.git
 RUN \
 	cd && \
 	mkdir .ccache && chown mani:mani .ccache && \
-	git clone ${ORIGIN} flashrom
+	git clone ${ORIGIN} flashprog
 
 ARG IDENT=mani
 ARG CCACHE_MAX=32M
diff --git a/util/manibuilder/Dockerfile.git b/util/manibuilder/Dockerfile.git
index 92549a3..10d7aa6 100644
--- a/util/manibuilder/Dockerfile.git
+++ b/util/manibuilder/Dockerfile.git
@@ -2,5 +2,5 @@
 
 RUN	apk add git-daemon
 EXPOSE	9418
-VOLUME	["/git/flashrom.git"]
-CMD	["daemon", "--reuseaddr", "--export-all", "--base-path=/git", "/git/flashrom.git"]
+VOLUME	["/git/flashprog.git"]
+CMD	["daemon", "--reuseaddr", "--export-all", "--base-path=/git", "/git/flashprog.git"]
diff --git a/util/manibuilder/Dockerfile.ubuntu b/util/manibuilder/Dockerfile.ubuntu
index 1762506..b9b818f 100644
--- a/util/manibuilder/Dockerfile.ubuntu
+++ b/util/manibuilder/Dockerfile.ubuntu
@@ -27,11 +27,11 @@
 ENV GIT_SSL_NO_VERIFY=1
 USER mani
 
-ARG ORIGIN=https://review.coreboot.org/flashrom-stable.git
+ARG ORIGIN=https://review.sourcearcade.org/flashprog.git
 RUN \
 	cd && \
 	mkdir .ccache && chown mani:mani .ccache && \
-	git clone ${ORIGIN} flashrom
+	git clone ${ORIGIN} flashprog
 
 ARG IDENT=mani
 ARG CCACHE_MAX=32M
diff --git a/util/manibuilder/Makefile b/util/manibuilder/Makefile
index 3ae1e15..47e3415 100644
--- a/util/manibuilder/Makefile
+++ b/util/manibuilder/Makefile
@@ -48,7 +48,7 @@
 
 $(ALL_TAGS): export QUIET_SETUP=$(QUIET_TEST)
 $(ALL_TAGS): export TEST_REMOTE?=$(if $(TEST_LOCAL),\
-					git://mani-git/flashrom.git,\
+					git://mani-git/flashprog.git,\
 					origin)
 $(ALL_TAGS): export TEST_REVISION?=$(if $(TEST_LOCAL),HEAD,main)
 $(ALL_TAGS): %: %-check-build mani-net $(if $(TEST_LOCAL),local-git)
@@ -127,7 +127,7 @@
 	fi; \
 	docker run --rm --detach \
 		--name mani-git \
-		--volume=$(TEST_LOCAL_GIT):/git/flashrom.git:ro \
+		--volume=$(TEST_LOCAL_GIT):/git/flashprog.git:ro \
 		--network=manibuilder \
 		mani/git $(if $(QUIET_SETUP),>/dev/null)
 
diff --git a/util/manibuilder/README.md b/util/manibuilder/README.md
index ece2317..adbdfe7 100644
--- a/util/manibuilder/README.md
+++ b/util/manibuilder/README.md
@@ -15,7 +15,7 @@
 target, for instance `alpine:amd64-v3.7`. These targets will
 automatically check for existence of their respective *Docker*
 images (sub target <tag>-check-build), and build them if necessary
-(<tag>-build). Finally, flashrom revision `$(TEST_REVISION)` is
+(<tag>-build). Finally, flashprog revision `$(TEST_REVISION)` is
 fetched and build tested.
 
 The results will be kept by *Docker* as stopped containers and
@@ -62,12 +62,12 @@
 
     $ make debian-debootstrap:mips-sid-shell
     [...]
-    mani@63536fc102a5:~/flashrom$ make
+    mani@63536fc102a5:~/flashprog$ make
     [...]
-    cc -MMD -Os -Wall -Wshadow -Werror -I/usr/include/libusb-1.0  -D'CONFIG_DEFAULT_PROGRAMMER=PROGRAMMER_INVALID' -D'CONFIG_DEFAULT_PROGRAMMER_ARGS="''"' -D'CONFIG_SERPROG=1' -D'CONFIG_PONY_SPI=1' -D'CONFIG_BITBANG_SPI=1' -D'CONFIG_GFXNVIDIA=1' -D'CONFIG_SATASII=1' -D'CONFIG_ATAVIA=1' -D'CONFIG_IT8212=1' -D'CONFIG_FT2232_SPI=1' -D'CONFIG_USBBLASTER_SPI=1' -D'CONFIG_PICKIT2_SPI=1' -D'HAVE_FT232H=1'  -D'CONFIG_DUMMY=1' -D'CONFIG_DRKAISER=1' -D'CONFIG_NICINTEL=1' -D'CONFIG_NICINTEL_SPI=1' -D'CONFIG_NICINTEL_EEPROM=1' -D'CONFIG_OGP_SPI=1' -D'CONFIG_BUSPIRATE_SPI=1' -D'CONFIG_DEDIPROG=1' -D'CONFIG_DEVELOPERBOX_SPI=1' -D'CONFIG_LINUX_MTD=1' -D'CONFIG_LINUX_SPI=1' -D'CONFIG_CH341A_SPI=1' -D'CONFIG_DIGILENT_SPI=1' -D'NEED_PCI=1'  -D'NEED_RAW_ACCESS=1' -D'NEED_LIBUSB0=1' -D'NEED_LIBUSB1=1' -D'HAVE_UTSNAME=1' -D'HAVE_CLOCK_GETTIME=1' -D'FLASHROM_VERSION="p1.0-141-g9cecc7e"' -o libflashrom.o -c libflashrom.c
-    libflashrom.c:386:12: error: 'flashrom_layout_parse_fmap' defined but not used [-Werror=unused-function]
-     static int flashrom_layout_parse_fmap(struct flashrom_layout **layout,
+    cc -MMD -Os -Wall -Wshadow -Werror -I/usr/include/libusb-1.0  -D'CONFIG_DEFAULT_PROGRAMMER=PROGRAMMER_INVALID' -D'CONFIG_DEFAULT_PROGRAMMER_ARGS="''"' -D'CONFIG_SERPROG=1' -D'CONFIG_PONY_SPI=1' -D'CONFIG_BITBANG_SPI=1' -D'CONFIG_GFXNVIDIA=1' -D'CONFIG_SATASII=1' -D'CONFIG_ATAVIA=1' -D'CONFIG_IT8212=1' -D'CONFIG_FT2232_SPI=1' -D'CONFIG_USBBLASTER_SPI=1' -D'CONFIG_PICKIT2_SPI=1' -D'HAVE_FT232H=1'  -D'CONFIG_DUMMY=1' -D'CONFIG_DRKAISER=1' -D'CONFIG_NICINTEL=1' -D'CONFIG_NICINTEL_SPI=1' -D'CONFIG_NICINTEL_EEPROM=1' -D'CONFIG_OGP_SPI=1' -D'CONFIG_BUSPIRATE_SPI=1' -D'CONFIG_DEDIPROG=1' -D'CONFIG_DEVELOPERBOX_SPI=1' -D'CONFIG_LINUX_MTD=1' -D'CONFIG_LINUX_SPI=1' -D'CONFIG_CH341A_SPI=1' -D'CONFIG_DIGILENT_SPI=1' -D'NEED_PCI=1'  -D'NEED_RAW_ACCESS=1' -D'NEED_LIBUSB0=1' -D'NEED_LIBUSB1=1' -D'HAVE_UTSNAME=1' -D'HAVE_CLOCK_GETTIME=1' -D'FLASHPROG_VERSION="p1.0-141-g9cecc7e"' -o libflashprog.o -c libflashprog.c
+    libflashprog.c:386:12: error: 'flashprog_layout_parse_fmap' defined but not used [-Werror=unused-function]
+     static int flashprog_layout_parse_fmap(struct flashprog_layout **layout,
             ^~~~~~~~~~~~~~~~~~~~~~~~~~
     cc1: all warnings being treated as errors
-    make: *** [Makefile:1075: libflashrom.o] Error 1
+    make: *** [Makefile:1075: libflashprog.o] Error 1
     $ # uh-huh, might be a problem with big-endian #if foo
diff --git a/util/manibuilder/mani-wrapper.sh b/util/manibuilder/mani-wrapper.sh
index c3f5834..b2de31f 100644
--- a/util/manibuilder/mani-wrapper.sh
+++ b/util/manibuilder/mani-wrapper.sh
@@ -1,6 +1,6 @@
 #!/bin/sh
 
-cd /home/mani/flashrom/
+cd /home/mani/flashprog/
 
 if [ $# -eq 0 ]; then
 	exec "${DEVSHELL}"
diff --git a/util/shell.nix b/util/shell.nix
index 3c983fe..0389a5f 100644
--- a/util/shell.nix
+++ b/util/shell.nix
@@ -1,7 +1,7 @@
 with import <nixpkgs> {};
 
 stdenv.mkDerivation {
-	name = "flashrom";
+	name = "flashprog";
 
 	buildInputs = [
 		gcc
diff --git a/util/z60_flashrom.rules b/util/z60_flashprog.rules
similarity index 96%
rename from util/z60_flashrom.rules
rename to util/z60_flashprog.rules
index 9fd3330..4651e1e 100644
--- a/util/z60_flashrom.rules
+++ b/util/z60_flashprog.rules
@@ -25,8 +25,8 @@
 ## suitable for your respective distribution.
 ##
 
-ACTION!="add|change", GOTO="flashrom_rules_end"
-SUBSYSTEM!="usb|usb_device", GOTO="flashrom_rules_end"
+ACTION!="add|change", GOTO="flashprog_rules_end"
+SUBSYSTEM!="usb|usb_device", GOTO="flashprog_rules_end"
 
 # Amontec JTAGkey(2)
 # http://www.amontec.com/jtagkey.shtml
@@ -93,4 +93,4 @@
 # Winchiphead (WCH) CH341a based programmer
 ATTRS{idVendor}=="1a86", ATTRS{idProduct}=="5512", MODE="664", GROUP="plugdev"
 
-LABEL="flashrom_rules_end"
+LABEL="flashprog_rules_end"
diff --git a/util/flashrom_partial_write_test.sh b/util/flashprog_partial_write_test.sh
similarity index 81%
rename from util/flashrom_partial_write_test.sh
rename to util/flashprog_partial_write_test.sh
index 8e30fc6..ea1f35f 100755
--- a/util/flashrom_partial_write_test.sh
+++ b/util/flashprog_partial_write_test.sh
@@ -13,7 +13,7 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # This script attempts to test Flashrom partial write capability by writing
 # patterns of 0xff and 0x00 bytes to the lowest 128kB of flash. 128kB is chosen
 # since 64kB is usually the largest possible block size, so we will try to
 # cover at least two blocks with this test.
@@ -21,18 +21,18 @@
 EXIT_SUCCESS=0
 EXIT_FAILURE=1
 
-# The copy of flashrom to test. If unset, we'll assume the user wants to test
-# a newly built flashrom binary in the parent directory (this script should
-# reside in flashrom/util).
-if [ -z "$FLASHROM" ] ; then
-	FLASHROM="../flashrom"
+# The copy of flashprog to test. If unset, we'll assume the user wants to test
+# a newly built flashprog binary in the parent directory (this script should
+# reside in flashprog/util).
+if [ -z "$FLASHPROG" ] ; then
+	FLASHPROG="../flashprog"
 fi
-echo "testing flashrom binary: ${FLASHROM}"
+echo "testing flashprog binary: ${FLASHPROG}"
 
 OLDDIR=$(pwd)
 
 # test data location
-TMPDIR=$(mktemp -d -t flashrom_test.XXXXXXXXXX)
+TMPDIR=$(mktemp -d -t flashprog_test.XXXXXXXXXX)
 if [ "$?" != "0" ] ; then
 	echo "Could not create temporary directory"
 	exit $EXIT_FAILURE
@@ -50,16 +50,16 @@
 	exit $EXIT_FAILURE
 fi
 
-which flashrom > /dev/null
+which flashprog > /dev/null
 if [ "$?" != "0" ] ; then
-	echo "Please install a stable version of flashrom in your path."
-	echo "This will be used to compare the test flashrom binary and "
+	echo "Please install a stable version of flashprog in your path."
+	echo "This will be used to compare the test flashprog binary and "
 	echo "restore your firmware image at the end of the test."
 	exit $EXIT_FAILURE
 fi
 
-# Keep a copy of flashrom with the test data
-cp "$FLASHROM" "${TMPDIR}/"
+# Keep a copy of flashprog with the test data
+cp "$FLASHPROG" "${TMPDIR}/"
 cd "$TMPDIR"
 echo "Running test in ${TMPDIR}"
 
@@ -83,7 +83,7 @@
 
 echo "Reading BIOS image"
 BIOS="bios.bin"
-flashrom ${FLASHROM_PARAM} -r "$BIOS" > /dev/null
+flashprog ${FLASHPROG_PARAM} -r "$BIOS" > /dev/null
 echo "Original image saved as ${BIOS}"
 
 # $1: exit code
@@ -94,8 +94,8 @@
 		echo "Result: PASSED"
 	fi
 
-	echo "restoring original bios image using system's flashrom"
-	flashrom ${FLASHROM_PARAM} -w "$BIOS"
+	echo "restoring original bios image using system's flashprog"
+	flashprog ${FLASHPROG_PARAM} -w "$BIOS"
 	echo "test files remain in ${TMPDIR}"
 	cd "$OLDDIR"
 	exit "$1"
@@ -166,15 +166,15 @@
 	dd if=${ZERO_4K} of=${TESTFILE} bs=1 conv=notrunc seek=${offset} 2> /dev/null
 	dd if=${FF_4K} of=${TESTFILE} bs=1 conv=notrunc seek=$((${offset} + 4096)) 2> /dev/null
 
-	./flashrom ${FLASHROM_PARAM} -l layout_4k_aligned.txt -i 00_${i} -i ff_${i} -w "$TESTFILE" > /dev/null
+	./flashprog ${FLASHPROG_PARAM} -l layout_4k_aligned.txt -i 00_${i} -i ff_${i} -w "$TESTFILE" > /dev/null
 	if [ "$?" != "0" ] ; then
 		echo "failed to flash region"
 		do_exit "$EXIT_FAILURE"
 	fi
 
 	# download the entire ROM image and use diff to compare to ensure
-	# flashrom logic does not violate user-specified regions
-	flashrom ${FLASHROM_PARAM} -r difftest.bin > /dev/null
+	# flashprog logic does not violate user-specified regions
+	flashprog ${FLASHPROG_PARAM} -r difftest.bin > /dev/null
 	diff -q difftest.bin "$TESTFILE"
 	if [ "$?" != "0" ] ; then
 		echo "failed diff test"
@@ -247,7 +247,7 @@
 " > layout_unaligned.txt
 
 # reset the test file and ROM to the original state
-flashrom ${FLASHROM_PARAM} -w "$BIOS" > /dev/null
+flashprog ${FLASHPROG_PARAM} -w "$BIOS" > /dev/null
 cp "$BIOS" "$TESTFILE"
 
 i=0
@@ -266,15 +266,15 @@
 	dd if=${ZERO_4K} of=${TESTFILE} bs=1 conv=notrunc seek=${offset} 2> /dev/null
 	dd if=${FF_4K} of=${TESTFILE} bs=1 conv=notrunc seek=$((${offset} + 4096)) count=writelen 2> /dev/null
 
-	./flashrom ${FLASHROM_PARAM} -l layout_unaligned.txt -i 00_${i} -i ff_${i} -w "$TESTFILE" > /dev/null
+	./flashprog ${FLASHPROG_PARAM} -l layout_unaligned.txt -i 00_${i} -i ff_${i} -w "$TESTFILE" > /dev/null
 	if [ "$?" != "0" ] ; then
 		echo "failed to flash region"
 		do_exit "$EXIT_FAILURE"
 	fi
 
 	# download the entire ROM image and use diff to compare to ensure
-	# flashrom logic does not violate user-specified regions
-	flashrom ${FLASHROM_PARAM} -r difftest.bin > /dev/null
+	# flashprog logic does not violate user-specified regions
+	flashprog ${FLASHPROG_PARAM} -r difftest.bin > /dev/null
 	diff -q difftest.bin "$TESTFILE"
 	if [ "$?" != "0" ] ; then
 		echo "failed diff test"
@@ -13,7 +13,7 @@
 # GNU General Public License for more details.
 #
-# This script attempts to test Flashrom partial write capability by writing
+# This script attempts to test Flashprog partial write capability by writing
 # patterns of 0xff and 0x00 bytes to the lowest 128kB of flash. 128kB is chosen
 # since 64kB is usually the largest possible block size, so we will try to